package com.persagy.dmp.rwd.digital.dao;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.persagy.dmp.basic.dto.RequestData;
import com.persagy.dmp.digital.entity.ObjectDigital;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 对象数据 DAO
 * @author Charlie Yu
 * @date 2021-07-08
 */
public interface ObjectDigitalMapper extends BaseMapper<ObjectDigital> {
    /***
     * Description: 根据项目id查询对象列表
     * @param requestData : 请求参数
     * @param skip
     * @param size
     * @return : com.persagy.dmp.common.model.response.CommonResult<java.util.List<com.persagy.dmp.digital.entity.ObjectDigital>>
     * @author : lijie
     * @date :2021/8/24 16:40
     * Update By lijie 2021/8/24 16:40
     */
    List<List<ObjectDigital>> queryObjectDigitalsByProjectId(@Param("param") RequestData requestData, @Param("skip") Long skip, @Param("size") Long size);
    /***
     * Description: 根据上级id查询对象列表
     * @param requestData : 请求参数
     * @return : java.util.List<java.util.List<com.persagy.dmp.digital.entity.ObjectDigital>>
     * @author : lijie
     * @date :2021/8/25 9:49
     * Update By lijie 2021/8/25 9:49
     */
    List<List<ObjectDigital>> queryObjectListBySuperiorId(@Param("param") RequestData requestData);
    /***
     * Description: 查询指定楼层下所有指定空间类型的空间
     * @param requestData : 请求参数
     * @return : java.util.List<java.util.List<com.persagy.dmp.digital.entity.ObjectDigital>>
     * @author : lijie
     * @date :2021/8/30 10:26
     * Update By lijie 2021/8/30 10:26
     */
    List<List<ObjectDigital>> queryObjectListByFloorIdAndRoomFuncType(@Param("param") RequestData requestData);
    /***
     * Description:查询指定空间下所有指定对象类型的设备
     * @param requestData : 请求参数
     * @return : com.persagy.dmp.common.model.response.CommonResult<java.util.List<com.persagy.dmp.digital.entity.ObjectDigital>>
     * @author : lijie
     * @date :2021/8/30 17:03
     * Update By lijie 2021/8/30 17:03
     */
    List<List<ObjectDigital>> queryObjectListByRelIdAndClassCode(@Param("param") RequestData requestData);
    /***
     * Description: 按类型编码查询所有设备
     * @param requestData : 请求参数
     * @return : java.util.List<java.util.List<com.persagy.dmp.digital.entity.ObjectDigital>>
     * @author : lijie
     * @date :2021/8/30 17:44
     * Update By lijie 2021/8/30 17:44
     */
    List<List<ObjectDigital>> queryEquipListByClassCode(@Param("param") RequestData requestData);
}
