package com.persagy.dmp.basic.dto;

import com.alibaba.fastjson.annotation.JSONField;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.fasterxml.jackson.annotation.JsonAlias;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.persagy.dmp.basic.validations.QueryClassCodeVadition;
import com.persagy.dmp.basic.validations.QueryFloorIdVadition;
import com.persagy.dmp.basic.validations.QuerySpaceIdVadition;
import com.persagy.dmp.basic.validations.QuerySystemIdVadition;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.validation.constraints.NotBlank;
import java.util.List;
import java.util.Set;

/***
 * @Description: 统一的请求体封装对象
 * @author: lijie
 * @Date:2020/7/9 10:35
 * Update By lijie 2020/7/9 10:35
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class RequestData {

    /** 安装位置 */
    public static final String INSTALL_LOCATION_HUM = "installLocation";
    /** 生产厂家 */
    public static final String MANUFACTURER = "manufacturer";
    /** 设备状态 */
    public static final String EQUIP_STATUS_HUM = "equipStatus";
    /** 维保单位名称 */
    public static final String WARRANTER = "warranter";

    /**账号id*/
    @JsonAlias({"user_id"})
    @JsonProperty("userId")
    @JSONField(name = "userId",alternateNames = {"user_id"})
    private String userId;
    /**管理分区id*/
    @JsonAlias({"group_manage_zone_ids"})
    @JsonProperty("groupManageZoneIds")
    @JSONField(name = "groupManageZoneIds",alternateNames = {"group_manage_zone_ids"})
    private Set<String> groupManageZoneIds;
    /** 分页页码,从 1 开始 */
    @JsonAlias({"page"})
    @JsonProperty("page")
    @JSONField(name = "page",alternateNames = {"page"})
    private Long page;
    /** 每页行数 */
    @JsonAlias({"page_size","size","pageSize"})
    @JsonProperty("size")
    @JSONField(name = "size",alternateNames = {"page_size","size","pageSize"})
    private Long size;
    /** 筛选关键字,本地名称筛选 */
    @JsonAlias({"keyword"})
    @JsonProperty("keyword")
    @JSONField(name = "keyword",alternateNames = {"keyword"})
    private String keyword;
    /** 是否只统计总数 */
    @JsonAlias({"only_count","onlyCount"})
    @JsonProperty("onlyCount")
    @JSONField(name = "onlyCount",alternateNames = {"only_count","onlyCount"})
    private boolean onlyCount = false;
    /** 创建时间筛选范围 */
    @JsonAlias({"ctime","createTimeScope"})
    @JsonProperty("createTimeScope")
    @JSONField(name = "createTimeScope",alternateNames = {"ctime","createTimeScope"})
    private TimeScope createTimeScope;
    /** 返回信息点过滤,仅过滤infos内的信息点,基础信息点不过滤 */
    @JsonAlias({"return_infos","returnInfos"})
    @JsonProperty("returnInfos")
    @JSONField(name = "returnInfos",alternateNames = {"return_infos","returnInfos"})
    private Set<String> returnInfos;
    /** 查询有效数据,true,false */
    @JsonAlias({"valid_set","validSet"})
    @JsonProperty("validSet")
    @JSONField(name = "validSet",alternateNames = {"valid_set","validSet"})
    private Set<Integer> validSet;
    /** 集团编码 */
    @JsonAlias({"group_code","groupCode"})
    @JsonProperty("groupCode")
    @JSONField(name = "groupCode",alternateNames = {"group_code","groupCode"})
    private String groupCode;
    /** 项目id */
    @JsonAlias({"project_id","projectId"})
    @JsonProperty("projectId")
    @JSONField(name = "projectId",alternateNames = {"project_id","projectId"})
    private String projectId;
    /** 建筑id */
    @JsonAlias({"building_id","buildingId"})
    @JsonProperty("buildingId")
    @JSONField(name = "buildingId",alternateNames = {"building_id","buildingId"})
    private String buildingId;
    /** 楼层id */
    @JsonAlias({"floor_id","floorId"})
    @JsonProperty("floorId")
    @JSONField(name = "floorId",alternateNames = {"floor_id","floorId"})
    @NotBlank(message = "缺少必填项:楼层id", groups = {QueryFloorIdVadition.class})
    private String floorId;
    /** 楼层id */
    @JsonAlias({"space_id","spaceId"})
    @JsonProperty("spaceId")
    @JSONField(name = "spaceId",alternateNames = {"space_id","spaceId"})
    @NotBlank(message = "缺少必填项:空间id", groups = {QuerySpaceIdVadition.class})
    private String spaceId;
    /** 系统id */
    @JsonAlias({"system_id","systemId"})
    @JsonProperty("systemId")
    @JSONField(name = "systemId",alternateNames = {"system_id","systemId"})
    @NotBlank(message = "缺少必填项:空间id", groups = {QuerySystemIdVadition.class})
    private String systemId;
    /** 空间功能类型 */
    @JsonAlias({"room_func_type","roomFuncType"})
    @JsonProperty("roomFuncType")
    @JSONField(name = "roomFuncType",alternateNames = {"room_func_type","roomFuncType"})
    private String roomFuncType;
    /** 对象类型 */
    @JsonAlias({"class_code","classCode"})
    @JsonProperty("classCode")
    @JSONField(name = "classCode",alternateNames = {"class_code","classCode"})
    @NotBlank(message = "缺少必填项:对象类型",groups = {QueryClassCodeVadition.class})
    private String classCode;
    /** 对象关系id */
    @JsonAlias({"rel_id","relId"})
    @JsonProperty("relId")
    @JSONField(name = "relId",alternateNames = {"rel_id","relId"})
    private String relId;
    /** 关系Code */
    @JsonAlias({"rel_code","relCode"})
    @JsonProperty("relCode")
    @JSONField(name = "relCode",alternateNames = {"rel_code","relCode"})
    private String relCode;
    /** 对象分类 */
    @JsonAlias({"obj_type","objType"})
    @JsonProperty("objType")
    @JSONField(name = "objType",alternateNames = {"obj_type","objType"})
    private String objType;
    /** 设备id */
    @JsonAlias({"equipment_id","equipmentId"})
    @JsonProperty("equipmentId")
    @JSONField(name = "equipmentId",alternateNames = {"equipment_id","equipmentId"})
    private String equipmentId;
    /** 对象类型数组 */
    @JsonAlias({"class_codes","classCodes"})
    @JsonProperty("classCodes")
    @JSONField(name = "classCodes",alternateNames = {"class_codes","classCodes"})
    private Set<String> classCodes;
    /** 对象分类数组 */
    @JsonAlias({"obj_types","objTypes"})
    @JsonProperty("objTypes")
    @JSONField(name = "objTypes",alternateNames = {"obj_types","objTypes"})
    private Set<String> objTypes;
    /** 跳跃条数 */
    @JsonAlias({"skip"})
    @JsonProperty("skip")
    @JSONField(name = "skip",alternateNames = {"skip"})
    private Long skip;
    /** 关系code数组 */
    @JsonAlias({"relCodes","rel_codes"})
    @JsonProperty("relCodes")
    @JSONField(name = "relCodes",alternateNames = {"relCodes","rel_codes"})
    private Set<String> relCodes;
    /** 查询部件标记,true-查询,false-不查询 */
    @JsonAlias({"queryEcFlag","query_ec_flag"})
    @JsonProperty("queryEcFlag")
    @JSONField(name = "queryEcFlag",alternateNames = {"queryEcFlag","query_ec_flag"})
    private Boolean queryEcFlag=false;
    /** 部件关系码 */
    @JsonAlias({"ecRelCodes","ec_rel_codes"})
    @JsonProperty("ecRelCodes")
    @JSONField(name = "ecRelCodes",alternateNames = {"ecRelCodes","ec_rel_codes"})
    private Set<String> ecRelCodes;
    /** 过滤的对象id */
    @JsonAlias({"filterObjId","filter_obj_id"})
    @JsonProperty("filterObjId")
    @JSONField(name = "filterObjId",alternateNames = {"filterObjId","filter_obj_id"})
    private String filterObjId;
    /** 安装位置 */
    @JsonAlias({"installLocation","install_location"})
    @JsonProperty("installLocation")
    @JSONField(name = "installLocation",alternateNames = {"installLocation","install_location"})
    private String installLocation;
    /** 生产厂家 */
    @JsonAlias({"manufacturer"})
    @JsonProperty("manufacturer")
    @JSONField(name = "manufacturer",alternateNames = {"manufacturer","manufacturer"})
    private String manufacturer;
    /** 维保单位名称 */
    @JsonAlias({"warranter"})
    @JsonProperty("warranter")
    @JSONField(name = "warranter",alternateNames = {"warranter"})
    private String warranter;
    /** 设备状态 */
    @JsonAlias({"equipStatus","equip_status"})
    @JsonProperty("equipStatus")
    @JSONField(name = "equipStatus",alternateNames = {"equip_status","equipStatus"})
    private String equipStatus;
    /** 排序条件 */
    @JsonAlias({"orders"})
    @JsonProperty("orders")
    @JSONField(name = "orders",alternateNames = {"orders"})
    private List<OrderItem> orders;
    /** 码表数据code */
    @JsonAlias({"codes"})
    @JsonProperty("codes")
    @JSONField(name = "codes",alternateNames = {"codes"})
    private Set<String> codes;
    /** 码表数据code */
    @JsonAlias({"parentCode","parent_code"})
    @JsonProperty("parentCode")
    @JSONField(name = "parentCode",alternateNames = {"parentCode","parent_code"})
    private String parentCode;
    /** 码表类型 */
    @JsonAlias({"typeCode","type_code"})
    @JsonProperty("typeCode")
    @JSONField(name = "typeCode",alternateNames = {"typeCode","type_code"})
    private String typeCode;

}
